@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright © 2012-2018 Roberto Alsina and others.
+# Copyright © 2012-2019 Roberto Alsina and others.
 
 # Permission is hereby granted, free of charge, to any
 # person obtaining a copy of this software and associated
@@ -125,7 +125,7 @@ class Listings(Task):
                 title = os.path.basename(in_name)
                 needs_ipython_css = True
             elif in_name:
-                with open(in_name, 'r') as fd:
+                with open(in_name, 'r', encoding='utf-8') as fd:
                     try:
                         lexer = get_lexer_for_filename(in_name)
                     except Exception:
